==> gbook-0.13b.tar.bz2: gbook/gbook.i18n-pt-br.php <==
<?

/**
 * Internationalisation file for the GuestBook extension
 *
 *
 * Copyright (C) 2005-2006 Tino Reichardt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * @package MediaWiki
 * @subpackage Extensions
 * @author Tino Reichardt <milky dash gbook at mcmilk dot de>
 * @copyright © 2006 Tino Reichardt
 * tradução para o português feita por Leonardo Barichello (www.mais.mat.br)
 */


if (!defined('MEDIAWIKI')) die();

$msg = array(

# fields of the form
'f_name'          => "nome",
'f_origin'        => "local",
'f_ip'            => "ip",
'f_browser'       => "navegador",
'f_email'         => "e-mail",
'f_homepage'      => "site",
'f_captcha'       => "captcha",
'f_entry'         => "mensagem",

# buttons
'b_submit'        => "enviar",
'b_reply'         => "responder",
'b_change'        => "alterar",
'b_delete'        => "deletar",
'b_reset'         => "limpar",

# misc
'headline'        => "Mural de recados",
'hl_create'       => "Deixe a sua mensagem:",
'hl_modify'       => "Modificando uma mensagem:",
'new_entry'       => "Bem-vindo ao nosso livro de visitas. Clique [{{fullurl:Special:Guestbook|action=add}} '''aqui'''] para deixar sua mensagem.",
'entry_okay'      => "Sua mensagem foi adicionada com sucesso!",
'delete_okay'     => "Mensagem removida.",
'change_okay'     => "Mensagem modificada",
'show_entries'    => "Ver outras mensagens",
'captcha_desc'    => "Digite as letras e números da imagem.",
'captcha_fail'    => ">> Conteúdo incorreto, tente novamente.",
'err_name'        => ">> O campo 'nome' é obrigatório",
'err_entry'       => ">> O campo 'mensagem' é obrigatório",
'err_noentry'     => ">> Essa mensagem não existe.",
'err_captcha'     => ">> Digite as letras e números da mensagem."
);

?>

==> gbook-0.14b.tar.bz2: gbook/gbook.i18n-pt-br.php <==
<?php

/**
 * Internationalisation file for the GuestBook extension
 *
 *
 * Copyright (C) 2005-2006 Tino Reichardt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * @package MediaWiki
 * @subpackage Extensions
 * @author Tino Reichardt <milky dash gbook at mcmilk dot de>
 * @copyright © 2006 Tino Reichardt
 * tradução para o português feita por Leonardo Barichello (www.mais.mat.br)
 */


if (!defined('MEDIAWIKI')) die();

$msg = array(

# fields of the form
'f_name'          => "nome",
'f_origin'        => "local",
'f_ip'            => "ip",
'f_browser'       => "navegador",
'f_email'         => "e-mail",
'f_homepage'      => "site",
'f_captcha'       => "captcha",
'f_entry'         => "mensagem",

# buttons
'b_submit'        => "enviar",
'b_reply'         => "responder",
'b_change'        => "alterar",
'b_delete'        => "deletar",
'b_reset'         => "limpar",

# misc
'headline'        => "Mural de recados",
'hl_create'       => "Deixe a sua mensagem:",
'hl_modify'       => "Modificando uma mensagem:",
'new_entry'       => "Bem-vindo ao nosso livro de visitas. Clique [{{fullurl:$this->myAddPage|action=add}} '''aqui'''] para deixar sua mensagem.",
'entry_okay'      => "Sua mensagem foi adicionada com sucesso!",
'delete_okay'     => "Mensagem removida.",
'change_okay'     => "Mensagem modificada",
'show_entries'    => "Ver outras mensagens",
'captcha_desc'    => "Digite as letras e números da imagem.",
'captcha_fail'    => ">> Conteúdo incorreto, tente novamente.",
'err_name'        => ">> O campo 'nome' é obrigatório",
'err_entry'       => ">> O campo 'mensagem' é obrigatório",
'err_noentry'     => ">> Essa mensagem não existe.",
'err_captcha'     => ">> Digite as letras e números da mensagem."
);

?>
